@@ -61,7 +61,7 @@ class Bridge {
           }
           return false
         },
-        async evaluateWithContext($block, $locals) {
+        async evaluateWithContext ($block, $locals) {
           const $variables = Object.keys($locals)
           const $inputs = $variables.map(v => `$locals["${v}"]`)
           const $code = ($block.split('\n').length === 1 && !$block.includes('return ')) ? 'return ' + $block : $block
@@ -173,6 +173,12 @@ class Bridge {
     this.ipc.send({ r, val: v.valueOf() })
   }
 
+  async keys (r, ffid) {
+    const v = await this.m[ffid]
+    const keys = Object.getOwnPropertyNames(v)
+    this.ipc.send({ r, keys })
+  }
+
   free (r, ffid, attr, args) {
     for (const id of args) {
       delete this.m[id]
